
llmodify   -   Change attributes of a submitted job step

Purpose

Changes the attributes or characteristics of a submitted job.

Syntax
     
llmodify [-?] | [-H] | [-v] | [-q] | {-x <execution_factor> |
         -c <consumable_cpus> | -m <consumable_real_memory> |
         -W <wclimit_add_min> | -C <job_class> | -a <account_no> |
         -s <q_sysprio> | -p {preempt|nopreempt} } <jobstep>

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level, 
   service level date, and lowest level of the operating system to run 
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-x <execution_factor>
   For Gang scheduling only, specifies the execution factor value. 
   Valid values are 1 and 99.  This is a LoadLeveler administrator
   only option. 

   99       Makes a job step in RUNNING or STARTING state 
            non-preemptable.  All other job steps running on the same 
	    nodes are preempted until the non-preemptable job step 
	    finishes running or its execution factor is lowered.

   1        Returns a job step to the normal preemptable state.  This 
            value is the default.

-c <consumable_cpus>
   Specifies the consumable CPU value for an idle-like job step. 

   Allows the ConsumableCpus resource requirement to be reset to the 
   specified value. This value can be any integer equal to or greater 
   than zero (0) and should follow the rules for the resources keyword 
   in the job command file.

-m <consumable_real_memory>
   Specifies the consumable real memory value for an idle-like job step. 

   Allows the ConsumableMemory resource requirement to be reset to the 
   specified value. No units should be specified, as megabytes (MB) is 
   assumed. This value can be any integer equal or greater than zero 
   (0).

-W <wclimit_add_min>
   Specifies additional time in minutes to add to the wall clock limits 
   of a running-like job step. This option is for preventing a job step 
   from being killed due to the wall clock limits.  This is a 
   LoadLeveler administrator-only option. 

   Both the hard limit and soft limit are increased by the specified 
   value. This value can be any integer greater than 0.          

   The increase will only be effective if a limit was originally set 
   and not already exceeded. If you attempt to modify the wall clock 
   limit for a job step that is approaching its current wall clock 
   limit, it is possible for the current wall clock limit to expire 
   before it can be changed.
          
   Specifying llmodify -W will fail if the job step is extended into a 
   reservation. The reservations in conflict must be canceled before the 
   request to increase the job step's wall clock limit can be granted.

-C <job_class>
   Specifies the job class name.

   Allows the job class name to be reset to the specified value for an 
   idle-like job step. This value can be any string without white spaces.

-a <account_no>
   Specifies the account number.

   Allows the account number to be reset to the specified value for an 
   idle-like job step.

-s q_sysprio
   Specifies the job step priority. 

   This option allows the q_sysprio for a job step to be reset to the 
   specified integer value.  The new job step priority will be fixed.  
   Once the priority has been modified, it will no longer be changed if 
   the central manager recalculates priorities.  This is a LoadLeveler 
   administrator-only option.

-p {preempt|nopreempt}
   Specifies whether a job is preemptable or nonpreemptable.

jobstep
   Is the name of a job step to be modified using the form of
   host.jobid.stepid
   *  host: The name of the schedd machine to which the job was 
      submitted. The default is the local machine.
   *  jobid: The ID assigned to the job when it was submitted using the 
      llsubmit command. A jobid is required.
   *  stepid: The step ID assigned to the job when it was submitted 
      using the llsubmit command.  A stepid is required.

Description

All options are for the job step owner or a LoadLeveler administrator 
on an idle-like job step with the following exceptions: 
*  -p, -s, -x, and -W  are LoadLeveler administrator only options
*  -x 1 is valid for a job step in any state
*  -x 99 is valid only for a job step in RUNNING or STARTING state
*  -W is valid only for a job step in a running-like state

A request to mark a job step nonpreemptable will fail if the job step's 
expected end time extends into an existing reservation.

At the time a job step is modified, LoadLeveler does not check to make 
certain that the job step with the modified values can be scheduled to 
run.

To determine if a modification request is successful, issue the 
llq -x -l command and check the following field in the output.

Options                   Field to check                   
-------                   --------------
-x                        Execution Factor              
-c or -m                  Resources                       
-W                        Wall Clk Hard Limit/Wall Clk Soft Limit                      
-C                        Class                           
-a                        Account
-s                        q_sysprio                        
-p                        Preemptable                     

An idle-like state is one of the following job states:
*  Idle
*  Deferred
*  User Hold
*  System Hold
*  User & System Hold
*  Not Queued
*  Vacated
*  Vacate Pending
*  Rejected
*  Reject Pending

A running-like state is one of the following job states:
*  Checkpointing
*  Pending
*  Preempted
*  Preempt Pending
*  Resume Pending
*  Running
*  Starting

Examples

1. This example puts the job step c163n07.12.0 in a non-preemptable 
   state:
   
   llmodify -p nopreempt c163n07.12.0

2. To extend the wall clock limits of job step c163n07.12.0 by 30
   minutes: 

   llmodify -W 30 c163n07.12.0

Results

The following shows a sample system response for  llmodify -s 109
c163n07.12.0: 

llmodify: request has been sent to LoadLeveler.

llmodify returns the following exit values: 

0        The command ran successfully.
-1       An error occurred.

Security

LoadLeveler administrators and users can issue this command.
