
llpreempt - Preempt a submitted job step

Purpose

Preempts the job steps specified in the joblist argument using the 
preempt method specified in the preempt_method argument or resumes the 
jobs steps specified in the joblist argument. Only jobs that have been 
preempted with the preempt method of suspend through the llpreempt 
command or the ll_preempt subroutine can be resumed with this command.  
The llpreempt command cannot resume a job step that was preempted 
through the PREEMPT_CLASS rules or a job step that was preempted with a 
preempt method other than suspend.

Syntax      

llpreempt -? | -H | -v | [-q] [-r | -m method] { [-u userlist] 
          [-h hostlist] | [joblist] }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

 -v 
   Displays the name of the command, release number, service level, 
   service level date, and lowest level of the operating system to 
   run this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-r 
   Resumes the specified jobs. This option is valid only for jobs that 
   were preempted by the suspend method.

-m preempt_method     

   su       Indicates preempted jobs that are to be suspended.
            Suspended jobs will stay in the preempted state until
            the action is undone with the -r flag. The suspend method is 
	    the only valid preempt method for the GANG scheduler. This 
	    is the default. 

            Preemption using the suspend method is not supported by the  
	    LoadLeveler for Linux platforms.  On these platforms, the  
	    llpreempt command will have no effect if the suspend method 
	    is specified either explicitly as a command line option 
	    (-m su), or implicitly through the 
	    default_preempt_method = su configuration keyword. Note that 
	    su is the default value of the default_preempt_method 
	    keyword.

   vc       Indicates that preempted jobs are to be vacated. The
            preempted jobs will be terminated and remain in the job 
	    queue.  The job will be rescheduled to run as soon as 
	    resources for the job are available.

   rm       Indicates that preempted jobs are to be removed. The
            preempted jobs will be terminated and removed from the job 
	    queue. In order to rerun the job, you must resubmit the job 
	    to LoadLeveler.

   sh       Indicates that preempted jobs are to be put into system 
            hold. The preempted jobs will be terminated and remain in 
	    the job queue in system hold state. The jobs will remain in 
	    system hold until released by a LoadLeveler administrator 
	    using the llhold command. After being released, the job will 
	    go into the idle state where it will be rescheduled to run 
	    as soon as resources for the job are available.

   uh       Indicates that preempted jobs are to be put into user hold. 
            The preempted jobs will be terminated and remain in the job 
	    queue in user hold state. The jobs will remain in the user 
	    hold until released by the owner of the job step or by a 
	    LoadLeveler administrator using the llhold command. After 
	    being released, the job will go into the idle state where 
	    it will be rescheduled to run as soon as resources for the 
	    job are available.

-u userlist
   Specifies a blank-delimited list of user names.  When used with the 
   -h option, only the user's job steps monitored on the machines in the 
   hostlist are preempted.  When used alone, only the user's jobs 
   monitored by the machine issuing the command are preempted.

-h hostlist
   Specifies a blank-delimited list of host names.  All job steps
   monitored by these hosts are preempted.  When used with the -u 
   option, only the specified user's job steps monitored by these
   hosts are preempted.

joblist
   Specifies a blank-delimited list of job step IDs for the job steps to 
   be preempted. Each job step ID must be in the form 
   host.jobid.stepid where: 
   *  host - The name of the schedd machine to which the job step was 
      submitted. The default is the local machine.
   *  jobid - The job ID assigned to the job when it was submitted
      using the llsubmit command. A jobid is required.
   *  stepid - The step ID assigned to the job when it was submitted 
      using the llsubmit command. The default is to
      include all of the steps of the job.          

   If the -u or -h option is specified, the joblist is ignored.

Description

This is a LoadLeveler administrator command used for Gang, Backfill, and 
external schedulers only.  Regular users do not have the authority to 
run this command. This command can only be used when the preemption 
function is enabled (Gang, Backfill, or external schedulers with 
preemption enabled).  The only preempt method allowed when running the 
GANG scheduler is suspend (su).

Examples

1. This example requests that job step c163n07.12.0 be preempted by the 
   default preempt method: 

   llpreempt c163n07.12.0

2. This example requests that job step c163n07.12.0 be resumed:

   llpreempt -r c163n07.12.0

3. This example requests that all job steps owned by user frank and 
   monitored by host c52n01 be preempted by the system hold method:
   
   llpreempt -m sh -u frank -h c52n01

Results

The following shows a sample system response for the llpreempt command: 
       
llpreempt: request has been sent to LoadLeveler.

Security

LoadLeveler administrators can issue this command.
