
llqres - Query a reservation

Purpose

llqres - Returns information about reservations in LoadLeveler.

Syntax    

llqres  { -? | -H | -v | [-l|-r] [-s] [[-u user_list] [-g group_list]
        [-h host_list] [-b begin_time] [-e end_time] | 
	-R reservation_list] }

Flags
    
-?
   Provides a short usage message.

-H 
   Provides extended help information.
	
-v 
   Displays the name of the command, release number, service level, 
   service level date, and lowest level of the operating system to run 
   this release.

-l
   Specifies that a long listing be generated for each reservation to be 
   queried.

-r
   Specifies raw mode for output. Each reservation will occupy one line 
   with the output fields separated by an exclamation point (!).

-s 
   Specifies that short host names will be used in the output of machine 
   names.

-u user_list  
   Specifies a blank-delimited list of users. Reservations to be queried 
   are owned by one of these users.

-g group_list 
   Specifies a blank-delimited list of LoadLeveler groups. Reservations 
   to be queried are owned by one of these groups.

-h host_list 
   Specifies a blank-delimited list of machines. Reservations to be 
   queried use one or more of these machines.

-b begin_time
   Reservations to be queried are active at or after the specified begin 
   time. The -b flag can be used together with the -e flag to query
   reservations expected to be active between the begin and end times. 
   The begin_time must be specified using the format 
   [mm/dd[/[cc]yy]] HH:MM.  Hours must be specified using a 24-hour 
   clock.

-e end_time
   Reservations to be queried are active at or before the specified end 
   time. The -e flag can be used together with the -b flag to query 
   reservations expected to be active between the begin and end times.  
   The end_time must be specified using the format 
   [mm/dd[/[cc]yy]] HH:MM. Hours must be specified using a 24-hour 
   clock.

-R reservation_list
   Specifies a blank-delimited list of reservation IDs to be queried.  
   Input for reservation IDs take the form [host.]rid[.r] where: 
   *  host - Is the name of the schedd machine to which the reservation 
      was submitted. The default is the local machine.
   *  rid - Is the ID assigned to the reservation when it was created. 
      A reservation ID is required.
   *  r - Indicates that this is a reservation ID (r is optional).

   When -R is specified, -u, -g, and -h are ignored.

Description

All users can issue this command.  Reservations satisfying all criteria 
specified by -u, -g, -h, -b, and -e will be queried if more than one of 
these options are present. By default, the llqres command queries all 
existing reservations.

This command is for the BACKFILL scheduler only.

Examples

1. When issuing the llqres command, you should receive output similar to 
   the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.30.r     loadl     A   3/16  14:00    120      3
   c94n16.31.r     dave      W   3/17  02:00    420      4
   c94n16.35.r     carol     W   3/17  13:30    240      2

   When issuing the llqres -l command, you should receive output
   similar to the following: 

   =============== Reservation c94n16.ppd.pok.ibm.com.30.r ===============
                  ID: c94n16.ppd.pok.ibm.com.30.r
       Creation Time: Wed Mar 16 08:12:23 EDT 2005
               Owner: loadl
               Group: No_Group
          Start Time: Wed Mar 16 14:00:00 EDT 2005
            Duration: 120 minutes
   Expected End Time: Wed Mar 16 16:00:00 EDT 2005
              SHARED: no
      REMOVE_ON_IDLE: no
              Status: ACTIVE
         Modified By: loadl
   Modification Time: Wed Mar 16 10:21:14 EDT 2005
               Users: 0
              Groups: 1
                      loadlusr
               Nodes: 3
                      c94n01.ppd.pok.ibm.com
                      c94n11.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
           Job Steps: 0
         
   =============== Reservation c94n16.ppd.pok.ibm.com.31.r ===============
                  ID: c94n16.ppd.pok.ibm.com.31.r
       Creation Time: Wed Mar 16 10:55:18 EDT 2005
               Owner: dave
               Group: No_Group
          Start Time: Thu Mar 17 02:00:00 EDT 2005
            Duration: 420 minutes
   Expected End Time: Thu Mar 17 09:00:00 EDT 2005
              SHARED: no
      REMOVE_ON_IDLE: yes
              Status: WAITING
         Modified By: dave
   Modification Time: Wed Mar 16 10:55:18 EDT 2005
               Users: 0
              Groups: 0
               Nodes: 4
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
                      c94n16.ppd.pok.ibm.com
           Job Steps: 1
                      c94n16.ppd.pok.ibm.com.25.0
         
   =============== Reservation c94n16.ppd.pok.ibm.com.35.r ===============
                  ID: c94n16.ppd.pok.ibm.com.35.r
       Creation Time: Wed Mar 16 10:58:19 EDT 2005
               Owner: carol
               Group: No_Group
          Start Time: Thu Mar 17 13:30:00 EDT 2005
            Duration: 240 minutes
   Expected End Time: Thu Mar 17 17:30:00 EDT 2005
              SHARED: no
      REMOVE_ON_IDLE: no
              Status: WAITING
         Modified By: carol
   Modification Time: Wed Mar 16 10:58:19 EDT 2005
               Users: 2
                      jay
                      iris
              Groups: 0
               Nodes: 2
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
           Job Steps: 0

2. To determine if any reservations will be active on the machine
   c94n01 before performing an hours worth of maintenance beginning at 
   8:00 on 3/18/2005, issue the following command:
   
   llqres -b 03/18/2005 8:00 -e 3/18/2005 9:00 -h c94n01

   You should receive output similar to the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.31.r     dave      W   3/18  02:00    420      4

3. There are no job steps associated with a reservation in the 
   following example. The short form is used for host names: 

   llqres -r -s -R c94n16.30.r              

   You should receive output similar to the following: 

   c94n16.30.r!Wed Mar 16 08:12:23 EDT 2005!loadl!No_Group! \
         Wed Mar 16 14:00:00 EDT
   2005!120!Wed Mar 16 16:00:00 EDT 2005!no!no!ACTIVE!loadl! \
         Wed Mar 16 10:21:14 EDT
   2005!0!!1!loadlusr!3!c94n01,c94n11,c94n12!0!

4. There are job steps associated with a reservation in the
   following example.  The short form is used for host names: 

   llqres -r -s -R c94n16.31.r

   You should receive output similar to the following: 
   c94n16.31.r!Wed Mar 16 10:35:18 EDT 2005!dave!No_Group! \
         Thu Mar 17 02:00:00 EDT
   2005!420!Thu Mar 17 09:00:00 EDT 2005!no!yes!WAITING!dave! \
         Wed Mar 16 10:55:18 
   EDT 2005!0!!0!!4!c94n01,c94n02,c94n12,c94n16!1!c94n16.25.0
