
llstatus - Query machine status

Purpose

Returns status information about machines in the LoadLeveler cluster. 
It does not provide status on any NQS machine.

Syntax

llstatus  [-?] [-H] [-R] [-F] [-v] [-l] [-a] [-f category_list] 
          [-r category_list] [hostlist]

Flags

-?
   Provides a short usage message.

-H 
   Provides extended help information.

-R 
   Lists all of the machine consumable resources associated with all of 
   the machines in the LoadLeveler cluster (when specified alone). When 
   a host list is specified, the option only displays machine consumable 
   resources associated with the specified hosts. This option should not 
   be used with any other option.

-F 
   Lists all of the floating consumable resources associated with the 
   LoadLeveler cluster. This option should not be used with any other 
   option.

-v 
   Displays the name of the command, release number, service level, 
   service level date, and lowest level of the operating system to run 
   this release.

-l 
   Specifies that a long listing be generated for each machine for 
   which status is requested. If -l is not specified, the standard
   list, described below, is generated.

-a 
   Displays information for each virtual adapter followed by
   information for each physical adapter it manages.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows 
   you to create a customized version of the standard llstatus 
   listing. The output fields produced by this flag all have a fixed 
   length. The output is displayed in the order in which you specify 
   the categories. category_list can be one or more of the following:

   %a       Hardware architecture
   %act     Number of job steps dispatched by the schedd daemon on
            this machine
   %cm      Custom Metric value
   %cpu     Number of CPUs on this machine
   %d       Available disk space in the LoadLeveler execute directory
   %i       Number of seconds since last keyboard or mouse activity
   %inq     Number of job steps in the job queue of this schedd machine
   %l       Berkeley one-minute load average
   %m       Physical memory on this machine
   %mt      Maximum number of initiators that can be used simultaneously 
            on this machine
   %n       Machine name
   %o       Operating system on this machine
   %r       Number of initiators used by the startd daemon on this 
            machine
   %sca     Availability of the schedd daemon
   %scs     State of the schedd daemon
   %sta     Availability of the startd daemon
   %sts     State of the startd daemon
   %v       Available swap space (free paging space) of this machine

-r category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you 
   to create a customized version of the standard llstatus listing. The 
   output produced by this flag is considered raw, in that the fields 
   can be variable in length. The output is displayed in the order in 
   which you specify the formats. Output fields are separated by an 
   exclamation point (!). category_list can be one or more of the 
   categories listed under the -f flag.

hostlist
   Is a blank-delimited list of machines for which status is requested.

Description

If no hostlist is specified, all machines are queried.

If you have more than a few machines configured for LoadLeveler,
consider redirecting the output to a file when using the -l flag.

Each machine periodically updates the central manager with a snapshot 
of its situation. Since the information returned by using llstatus is a 
collection of such snapshots, all taken at varying times, the total 
picture may not be completely consistent.

Certain resources such as remote direct-memory access (RDMA) have their 
available value always calculated by startd. Available ConsumableCpus 
resources are calculated by startd if the value is specified as all in 
the administration file. When the value of a resource is calculated by 
startd, the llstatus command appends a plus (+) sign to the resource 
name in the output reports. Resources that are automatically created, 
such as RDMA, have a less than (<) sign appended to them.

Examples

This example requests a long status listing for machines named silver 
and gold:

llstatus -l silver gold

Results

The Standard Listing: The standard listing is generated when you do not 
specify the -l option with the llstatus command.

The standard listing includes the following fields: 

Name     Hostname of the machine.

Schedd   State of the schedd daemon, which can be one of the following:
         *  Down
         *  Drned (Drained)
         *  Drning (Draining)
         *  Avail (Available)

         For more information, see the description of the schedd daemon 
	 in LoadLeveler: Using and Administering.
   
InQ      Number of job steps in the job queue of this schedd machine.

Act      Number of job steps dispatched by the schedd daemon on this 
         machine.

Startd   State of the startd daemon, which can be:
         *  Busy
         *  Down
         *  Drned (Drained)
         *  Drning (Draining)
         *  Flush
         *  Idle
         *  None
         *  Run (Running)
         *  Suspnd (Suspend)

         For more information, see the description of the startd daemon 
	 in LoadLeveler: Using and Administering.     
	 
Run      The number of initiators used by the startd daemon to run
         LoadLeveler jobs on this machine. One initiator is used
         for each serial job step and one initiator is used for
         each task of a parallel job step.

LdAvg    Berkeley one-minute load average on this machine.

Idle     The number of seconds since keyboard or mouse activity in a
         login session was detected. Highest number displayed is 9999.

Arch     The hardware architecture of the machine as listed in the
         configuration file.

OpSys    The operating system on this machine.

Total Machines
         The standard listing includes the following summary fields:

         machines The number of machines in the cluster that have
                  made a status report to the Central Manager.

         jobs     The number of job steps in LoadLeveler job queues.

         running  The number of initiators used by all the startd
                  daemons in the LoadLeveler cluster. One initiator is 
		  used for each serial job step. One initiator is used 
		  for each task of a parallel job step.

Consumable Resources Listing: The llstatus command, issued with the -R 
option, generates a listing of all of the consumable resources 
associated with all of the machines in the LoadLeveler cluster. When a 
host list is specified, this option will only display resources 
associated with the specified hosts.

Floating Consumable Resources Listing: The llstatus command, issued with 
the -F option, generates a listing of all of the floating consumable 
resources associated with all of the machines in the LoadLeveler 
cluster. This option should not be specified with any other option.

Customized, Formatted Standard Listing: A customized and formatted
standard listing is generated when you specify llstatus with the
-f option.

Customized, Unformatted Standard Listing: A customized and unformatted 
(raw) standard listing is generated when you specify llstatus with the 
-r flag. Output fields are separated by an exclamation point (!).

Adapter Status Listing: When llstatus is issued with the -a flag
information is generated about the status of the adapters associated 
with all the machines in the LoadLeveler cluster.

The Long Listing: The long listing is generated when you specify the -l 
option with the llstatus command. Following the sample output is an 
explanation of all possible fields displayed by the llstatus command.

The long listing includes these fields: 

Adapter  Network adapter information associated with this machine.
         *  For a switch adapter, the information format is:
            adapter_name(network_type, interface_name,
            interface_address, multilink_address,
            switch_node_number or adapter_logical_id,
            available_adapter_windows/total_adapter_windows,
            available_device_memory/total_device_memory,
            adapter_fabric_connectivity, adapter_state)
         *  For non-switch adapters, the format is:
            adapter_name(network_type, interface_name,
            interface_address, multilink_address)


Arch     Hardware architecture of this machine.

AvailableClasses
         List of available classes and the associated number of
         available initiators on this machine.

Completed
         The number of job steps in this state on this schedd machine.

Config Time Stamp
         Date and time of last configuration or reconfiguration.

ConfiguredClasses
         List of configured classes and the associated number of
         configured initiators on this machine.

ConsumableResources
         List of consumable resources associated with this machines. 
	 Each element of this list has the format:
         resource_name(available, total).

CONTINUE The expression, defined following C conventions in the
         configuration file, that evaluates to true or false (T/F). 
	 This determines whether suspended jobs are continued on this 
	 machine.

Cpus     Number of CPUs on this machine.

CustomMetric
         This value can be the number assigned to the CUSTOM_METRIC 
	 keyword or the exit code of the executable associated with the 
	 CUSTOM_METRIC_COMMAND keyword or the default value of 1.

Disk     Available space, in kilobytes (less 512KB) in LoadLeveler's 
         execute directory on this machine.

DrainedClasses
         List of classes which have been drained. If a job step is in a 
	 class named on this list, that job step will not start on this 
	 machine.

DrainingClasses
         List of classes which are currently being drained on this 
	 machine. If a job step is in a class named on this list, that 
	 job step will not start on this machine.

Entered Current State
         Date and time when machine state was set.

FabricConnectivity
         Represents the current state of connectivity between the
         machine and the switch through the switch adapters. The format 
	 of the field is:  network_id: connectivity, network_id: 
	 connectivity... where connectivity is either 1 or 0. A value of
	 1 indicates an active connection from the machine to a given 
	 network_id through one of the switch adapters. 

         If a machine does not have switch adapters, the
         FabricConnectivity field has no meaning and should be ignored 
	 by the user.

Feature  Set of all features on this machine.

FreeLargePageMemory
         Free Large Page memory.

         In LoadLeveler for Linux, the FreeLargePageMemory field has no 
	 meaning and should be ignored by the user.

FreeRealMemory
         Free real memory, in megabytes, on this machine. This value 
	 should track closely with the "fre" value of the vmstat 
	 command and the "free" value of the svmon -G command whose 
	 units are 4KB blocks.

Held     The number of job steps in this state on this schedd machine.

Idle     The number of job steps in this state on this schedd machine.

Keyboard Idle
         Number of seconds since last keyboard or mouse activity.

KILL     The expression, defined following C conventions in the
         configuration file, that evaluates to true or false (T/F). 
	 This determines whether jobs running on this machine should be 
	 sent the SIGKILL signal.

LargePageMemory
         Configured Large Page physical memory.

         In LoadLeveler for Linux, the LargePageMemory field has no 
	 meaning and should be ignored by the user.

LargePageSize
         The size of a Large Page memory block. 

         In LoadLeveler for Linux, the LargePageSize field has no
         meaning and should be ignored by the user.

LoadAvg  Berkely one-minute load average on machine.

Machine  Fully qualified name of the machine.

Machine Mode
         The type of job this machine can run. This can be: batch,
         interactive, or general.

MACHPRIO Actual expression that determines machine priority, defined in 
         the configuration file.

MasterMachPriority
         The machine priority for the parallel master node.

Max_Starters
         Maximum number of initiators that can be used simultaneously 
	 on this machine.

Memory   Regular physical memory, in megabytes, on this machine.

Name     Hostname of the machine.

OpSys    Operating system on this machine.

PagesFreed
         Pages freed per second. This value corresponds to the "fr" 
	 value of the vmstat command output. In LoadLeveler for Linux, 
	 the PagesFreed field has no meaning and should be ignored by 
	 the user.

PagesPaged In
         Pages paged in from paging space per second. This value
         corresponds to the "pi" value of the vmstat command output. 

         In LoadLeveler for Linux, the PagesPagedIn field has no meaning
         and should be ignored by the user.

PagesPagedOut
         Pages paged out to paging space per second. This value
         corresponds to the "po" value of the vmstat command output. 

         In LoadLeveler for Linux, the PagesPagedOut field has no
         meaning and should be ignored by the user.

PagesScanned
         Pages scanned by the page-replacement algorithm per second. 
	 This value corresponds to the "sr" value of the vmstat 
	 command output. 

         In LoadLeveler for Linux, the PagesScanned field has no
         meaning and should be ignored by the user.

Pending  The number of job steps in this state on this schedd machine.

Pool     The identifier of the pool where this startd machine is
         located.

Removed  The number of job steps in this state on this schedd machine.

Remove Pending
         The number of job steps in this state on this schedd machine.

ReservationPermitted
         Indicates whether or not the reservation can be reserved. It is 
	 displayed as T or F (true or false).

Reservations
         The IDs of reservations that will use the node now or in the 
	 future.

Running  The number of initiators used by the startd daemon to run
         LoadLeveler jobs. One initiator is used for each serial job 
	 step. One initiator is used for each task of a parallel job 
	 step.

Running steps
         The list of job steps currently running on this machine.

ScheddAvail
         Flag indicating if machine is running a schedd daemon
         (0=no, 1=yes).

ScheddRunning
         The number of job steps submitted to this machine that are
         running somewhere in the LoadLeveler cluster.

ScheddState
         The state of the schedd daemon on this machine.

Speed    Speed associated with the machine.

START    The expression, defined following C conventions in the
         configuration file, that evaluates to true or false (T/F). 
	 This determines whether jobs can be started on this machine.

StartdAvail
         Flag indicating if machine is running a startd daemon
         (0=no, 1=yes).

Starting The number of job steps in this state on this schedd machine.

State    State of the startd daemon, which can be:
         *  Busy
         *  Down
         *  Drained
         *  Draining
         *  Flush
         *  Idle
         *  None
         *  Running
         *  Suspend

         For more information, see the description of the startd daemon 
	 in LoadLeveler: Using and Administering.

Subnet   The TCP/IP subnet that this machine resides on.

SUSPEND  The expression, defined following C conventions in the
         configuration file, that evaluates to true or false (T/F). 
	 This determines whether running jobs should be suspended on 
	 this machine.

SYSPRIO  Actual expression that determines overall system priority of a 
         job step. Defined in the configuration file.

TimeStamp
         The date and time the central manager last received a status 
	 update from this schedd machine.

Tmp      Available space, in kilobytes (less than 512 KB) in the /tmp 
         directory on this machine.

Total Jobs
         The number of total job steps submitted to this schedd machine.

TotalMemory
         The sum of configured regular and Large Page memory.

Unexpanded
         The number of job steps in this state on this schedd machine.

VACATE   The expression, defined following C conventions in the
         configuration file, that evaluates to true or false (T/F). 
	 This determines whether suspended jobs are vacated on this 
	 machine.

Virtual Memory
         Available swap space (free paging space) in kilobytes, on
         this machine.

Security

LoadLeveler administrators and users can issue this command.
